"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerationReadingStoredEventHandler = void 0;
const cqrs_1 = require("@nestjs/cqrs");
const common_1 = require("@nestjs/common");
const GenerationReadingStored_event_1 = require("../events/GenerationReadingStored.event");
const issue_service_1 = require("../issue.service");
const repositories_1 = require("../repositories");
const GetTransferSites_query_1 = require("../queries/GetTransferSites.query");
const issue_batch_1 = require("../batch/issue.batch");
let GenerationReadingStoredEventHandler = class GenerationReadingStoredEventHandler {
    constructor(etrRepository, queryBus, eventBus) {
        this.etrRepository = etrRepository;
        this.queryBus = queryBus;
        this.eventBus = eventBus;
        this.logger = new common_1.Logger(issue_service_1.IssueService.name);
    }
    async handle(event) {
        const { generatorId, energyValue, transferDate, fromTime, toTime, metadata } = event.data;
        const sites = await this.queryBus.execute(new GetTransferSites_query_1.GetTransferSitesQuery({ generatorId }));
        if (!sites) {
            this.logger.log(`No sites queries for ${generatorId}`);
            return;
        }
        await this.etrRepository.createNew({
            buyerAddress: sites.buyerAddress,
            sellerAddress: sites.sellerAddress,
            volume: energyValue,
            transferDate,
            certificateData: {
                generatorId,
                fromTime: fromTime.toISOString(),
                toTime: toTime.toISOString(),
                metadata
            }
        });
        this.eventBus.publish(new issue_batch_1.AwaitingIssuanceEvent());
    }
};
GenerationReadingStoredEventHandler = __decorate([
    cqrs_1.EventsHandler(GenerationReadingStored_event_1.GenerationReadingStoredEvent),
    __param(0, common_1.Inject(repositories_1.ENERGY_TRANSFER_REQUEST_REPOSITORY)),
    __metadata("design:paramtypes", [Object, cqrs_1.QueryBus,
        cqrs_1.EventBus])
], GenerationReadingStoredEventHandler);
exports.GenerationReadingStoredEventHandler = GenerationReadingStoredEventHandler;
//# sourceMappingURL=GenerationReadingStoredEvent.handler.js.map