"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferService = void 0;
const common_1 = require("@nestjs/common");
const origin_247_certificate_1 = require("@energyweb/origin-247-certificate");
const EnergyTransferRequest_repository_1 = require("./repositories/EnergyTransferRequest.repository");
const EnergyTransferRequest_1 = require("./EnergyTransferRequest");
const lodash_1 = require("lodash");
const configuration_1 = require("./batch/configuration");
let TransferService = class TransferService {
    constructor(certificateService, etrRepository, batchConfiguration) {
        this.certificateService = certificateService;
        this.etrRepository = etrRepository;
        this.batchConfiguration = batchConfiguration;
    }
    async transferTask() {
        const etrs = await this.etrRepository.findByState(EnergyTransferRequest_1.State.TransferAwaiting);
        const chunkedEtrs = lodash_1.chunk(etrs, this.batchConfiguration.transferBatchSize);
        for (const chunk of chunkedEtrs) {
            await this.transferCertificates(chunk);
        }
    }
    async transferCertificates(etrs) {
        etrs.forEach((etr) => etr.transferStarted());
        await this.etrRepository.saveManyInTransaction(etrs);
        try {
            const result = await this.certificateService.batchTransfer(etrs.map((etr) => ({
                fromAddress: etrs[0].sites.sellerAddress,
                toAddress: etrs[0].sites.buyerAddress,
                certificateId: etr.certificateId,
                energyValue: etr.volume
            })));
            if (!result.success) {
                throw new Error(result.message ?? 'Unknown transfer error');
            }
            etrs.forEach((etr) => etr.transferFinished());
        }
        catch (e) {
            etrs.forEach((etr) => etr.transferError(e.message));
        }
        await this.etrRepository.saveManyInTransaction(etrs);
    }
};
TransferService = __decorate([
    common_1.Injectable(),
    __param(0, common_1.Inject(origin_247_certificate_1.CERTIFICATE_SERVICE_TOKEN)),
    __param(1, common_1.Inject(EnergyTransferRequest_repository_1.ENERGY_TRANSFER_REQUEST_REPOSITORY)),
    __param(2, common_1.Inject(configuration_1.BATCH_CONFIGURATION_TOKEN)),
    __metadata("design:paramtypes", [origin_247_certificate_1.CertificateService, Object, Object])
], TransferService);
exports.TransferService = TransferService;
//# sourceMappingURL=transfer.service.js.map